summaryrefslogtreecommitdiff
path: root/gcc/tree-if-conv.c
diff options
context:
space:
mode:
authorspop <spop@138bc75d-0d04-0410-961f-82ee72b054a4>2010-05-26 16:45:47 +0000
committerspop <spop@138bc75d-0d04-0410-961f-82ee72b054a4>2010-05-26 16:45:47 +0000
commitd11c70fa87b29086fc127f15a4b8da865439919d (patch)
tree55966bc53e8322ffd7f3fbae48d059669ba77146 /gcc/tree-if-conv.c
parent6388cfe24f7ecbdc2ba2d4c80638ea6c95ba07c2 (diff)
downloadgcc-d11c70fa87b29086fc127f15a4b8da865439919d.tar.gz
Fix comments.
2010-05-26 Sebastian Pop <sebastian.pop@amd.com> * tree-if-conv.c: Update copyright years. Fix comments. Fix indentation. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@159880 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/tree-if-conv.c')
-rw-r--r--gcc/tree-if-conv.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/gcc/tree-if-conv.c b/gcc/tree-if-conv.c
index adbdfd8fcc2..127b5e36b59 100644
--- a/gcc/tree-if-conv.c
+++ b/gcc/tree-if-conv.c
@@ -589,11 +589,11 @@ if_convertible_loop_p (struct loop *loop)
edge_iterator ei;
basic_block exit_bb = NULL;
/* Handle only inner most loop. */
if (!loop || loop->inner)
{
if (dump_file && (dump_flags & TDF_DETAILS))
- fprintf (dump_file, "not inner most loop\n");
+ fprintf (dump_file, "not innermost loop\n");
return false;
}
@@ -631,7 +631,7 @@ if_convertible_loop_p (struct loop *loop)
if (!ifc_bbs)
{
if (dump_file && (dump_flags & TDF_DETAILS))
- fprintf (dump_file,"Irreducible loop\n");
+ fprintf (dump_file, "Irreducible loop\n");
free_dominance_info (CDI_POST_DOMINATORS);
return false;
}
@@ -662,7 +662,7 @@ if_convertible_loop_p (struct loop *loop)
}
if (dump_file)
- fprintf (dump_file,"Applying if-conversion\n");
+ fprintf (dump_file, "Applying if-conversion\n");
free_dominance_info (CDI_POST_DOMINATORS);
return true;
@@ -1020,7 +1020,7 @@ tree_if_conversion (struct loop *loop)
if (!if_convertible_loop_p (loop))
{
if (dump_file && (dump_flags & TDF_DETAILS))
- fprintf (dump_file,"-------------------------\n");
+ fprintf (dump_file, "-------------------------\n");
if (ifc_bbs)
{
free (ifc_bbs);
@@ -589,11 +589,11 @@ if_convertible_loop_p (struct loop *loop)
edge_iterator ei;
basic_block exit_bb = NULL;
- /* Handle only inner most loop. */
+ /* Handle only innermost loop. */
if (!loop || loop->inner)
{